@@ -91,31 +91,27 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
   },
   render_axis_h = function(self,scale_details, theme) zeroGrob(), #not required
   render_axis_v = function(self,scale_details, theme) zeroGrob(), #not required
-  render_fg     = function(self,scale_details, theme){
-    items = list()
-    mask  = calc_element('tern.panel.mask.show',theme) %||% TRUE
-    extrm = .get.tern.extremes(self,scale_details)
-    if(.theme.get.gridsontop(theme))
-      items = .render.grids(self,extrm,scale_details,theme,items,onBackground = TRUE)
-    else
-      items = .render.grids(self,extrm,scale_details,theme,items,onBackground = FALSE)
-    if(.theme.get.bordersontop(theme))
-      items = .render.borders(self,extrm,theme,items)
-    items   = .render.arrows(self,extrm,scale_details,theme,items)
-    items   = .render.titles(self,extrm,scale_details,theme,items)
-    gTree(children = do.call("gList", items))
-  },
   render_bg     = function(self,scale_details, theme){
-    items = list()
-    mask  = calc_element('tern.panel.mask.show',theme) %||% TRUE
+    items = list() 
     extrm = .get.tern.extremes(self,scale_details)
     items = .render.background(self,extrm,theme,items)
-    if(!.theme.get.gridsontop(theme))
-      items = .render.grids(self,extrm,scale_details,theme,items,onBackground = TRUE)
-    if(!.theme.get.bordersontop(theme))
-      items = .render.borders(self,extrm,theme,items)
+    if(!.theme.get.gridsontop(theme)){
+      items = .render.grid(self,extrm,scale_details,theme,items)
+      if(!.theme.get.showmask(theme))
+        items = .render.fgset(self,extrm,scale_details,theme,items)
+    }
     gTree(children = do.call("gList",items))
   },
+  render_fg     = function(self,scale_details, theme){
+    items = list() 
+    extrm = .get.tern.extremes(self,scale_details)
+    if(.theme.get.gridsontop(theme)){
+      items = .render.grid( self,extrm,scale_details,theme,items)
+      items = .render.fgset(self,extrm,scale_details,theme,items)
+    }
+    items = .render.titles(self,extrm,scale_details,theme,items)
+    gTree(children = do.call("gList", items))
+  },
   train = function(self, scale_details) {
     train_cartesian <- function(scale_details,limits,name,continuousAmount) {
       if (self$expand) {
@@ -141,8 +137,6 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
     #Adjust for rotation
     extremes        = .get.tern.extremes(self,list(x.range=self$limits$x,
                                                    y.range=self$limits$y))[,c('x','y')]
-    #print(extremes)
-    #print(self$limits)
     currentMidpoint = c(mean(self$limits$x),mean(self$limits$y))
     ternaryMidpoint = apply(extremes,2,function(x){mean(range(x))})
     shift           = 0*(currentMidpoint - ternaryMidpoint)
@@ -215,19 +209,19 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
 
 .theme.get.showtitles <- function(theme){
   showtitles = calc_element("tern.axis.title.show",theme=theme)
-  ifthenelse(is.logical(showtitles),showtitles[1],getOption("tern.showtitles"))
+  ifthenelse(is.logical(showtitles),showtitles[1],getOption("tern.title.show"))
 }
 .theme.get.showlabels <- function(theme){
   showlabels = calc_element("tern.axis.text.show",theme=theme)
-  ifthenelse(is.logical(showlabels),showlabels[1],getOption("tern.showlabels"))
+  ifthenelse(is.logical(showlabels),showlabels[1],getOption("tern.text.show"))
 }
 .theme.get.showgrid.major <- function(theme){
   showgrid   = calc_element("tern.panel.grid.major.show",theme=theme)
-  ifthenelse(is.logical(showgrid),showgrid[1],getOption("tern.showgrid.major"))
+  ifthenelse(is.logical(showgrid),showgrid[1],getOption("tern.grid.major.show"))
 }
 .theme.get.showgrid.minor <- function(theme){
   showgrid   = calc_element("tern.panel.grid.minor.show",theme=theme)
-  ifthenelse(is.logical(showgrid),showgrid[1],getOption("tern.showgrid.minor"))
+  ifthenelse(is.logical(showgrid),showgrid[1],getOption("tern.grid.minor.show"))
 }
 .theme.get.outside       <- function(theme){
   outside     = calc_element("tern.axis.ticks.outside",theme=theme)
@@ -235,16 +229,21 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
 }
 .theme.get.showprimary   <- function(theme){
   showprimary = calc_element("tern.axis.ticks.primary.show",theme=theme)
-  ifthenelse(is.logical(showprimary), showprimary[1],getOption("tern.ticks.showprimary"))
+  ifthenelse(is.logical(showprimary), showprimary[1],getOption("tern.ticks.primary.show"))
 }
 .theme.get.showsecondary <- function(theme){
   showsecondary = calc_element("tern.axis.ticks.secondary.show",theme=theme)
-  ifthenelse(is.logical(showsecondary),showsecondary[1],getOption("tern.ticks.showsecondary"))
+  ifthenelse(is.logical(showsecondary),showsecondary[1],getOption("tern.ticks.secondary.show"))
 }
-.theme.get.showarrows    <- function(theme){
+.theme.get.showarrows <- function(theme){
   showarrows   = calc_element('tern.axis.arrow.show',theme=theme)
-  ifthenelse(is.logical(showarrows),showarrows[1],getOption("tern.showarrows"))
+  ifthenelse(is.logical(showarrows),showarrows[1],getOption("tern.arrow.show"))
 }
+.theme.get.showmask <- function(theme){
+  showmask = calc_element('tern.panel.mask.show',theme=theme)
+  ifthenelse(is.logical(showmask),showmask[1],getOption('tern.mask.show'))
+} 
+
 .theme.get.label <- function(self,n,d=n,suffix=''){
   x      = function(n,s) sprintf("%s%s",n,s)
   if(!is.character(n)) return('')
@@ -257,7 +256,9 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
   tryCatch({
     angle = calc_element('tern.panel.rotate',self$theme)
     return(ifthenelse(is.finite(angle),angle,0)[1])
-  },error=function(e){ warning(e) })
+  },error=function(e){ 
+    warning(e) 
+  })
   return(0)
 }
 
@@ -269,10 +270,106 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
 # -Precession Arrows & Markers
 # _Apex Titles
 #----------------------------------------------------------------------------------
-.render.background <- function(self,data.extreme,theme,items){
-  grob  <- zeroGrob()
+.get.grid.data <- function(self,theme,data.extreme,X,major=TRUE,angle=0,angle.text=0){
+  clockwise   = .theme.get.clockwise(theme)
+  seq.tlr     = c("T","L","R")
+  ix          = which(X == seq.tlr)
+  existing    = data.frame()
+  
   tryCatch({
-      e     <- calc_element('tern.plot.background',theme=theme,verbose=F)
+    scale = self$scales[[X]]
+    
+    #DETERMINE THE BREAKS
+    breaks <- if(major) scale$breaks else scale$minor_breaks
+    
+    #BYPASS IF NECESSARY
+    if(length(breaks) == 0) 
+      return(existing)
+    
+    labels <- ifthenelse(major,scale$labels,"")
+    labels <- as.character(ifthenelse(identical(labels,waiver()),100*breaks,labels))
+    
+    #major & minor ticklength
+    tl.major <- tl.minor <- 0
+    tryCatch({
+      tl.major <- convertUnit(theme$tern.axis.ticks.length.major,"npc",valueOnly=T)
+    },error=function(e){ warning(e) })
+    tryCatch({
+      tl.minor <- convertUnit(theme$tern.axis.ticks.length.minor,"npc",valueOnly=T)
+    },error=function(e){  warning(e) })
+    
+    #Assign new id.
+    id     <- (max(existing$ID,0) + 1)
+    limits <- is.numericor(scale$limits,c(0,1))
+    ix     <- min(ix,ifthenelse(major,length(tl.major),length(tl.minor)))
+    majmin <- ifthenelse(major,"major","minor")  #Major or Minor Element Name part.
+    
+    #The new dataframe
+    new            <- data.frame(ID = id,Scale=X,breaks,Labels=labels,Major=major)
+    new            <- subset(new,breaks >= min(limits) & breaks <= max(limits))
+    new$Prop       <- (new$breaks - min(limits)) / abs(diff(limits))
+    new$TickLength <- ifthenelse(major,tl.major[ix],tl.minor[ix])
+    new$NameText   <- paste0("tern.axis.text.",X)
+    new$NameTicks  <- paste0("tern.axis.ticks.",majmin,".",X)
+    new$NameGrid   <- paste0("tern.panel.grid.",majmin,".",X)
+    new$Major      <- major
+    
+    ##Start and finish positions of scale.
+    out       <- c("x","y")
+    
+    #Start indexes.
+    ix.s <- which(seq.tlr == X);
+    finish <- as.numeric(data.extreme[ix.s,out])
+    
+    #For Ticks
+    ix.f <- ifthenelse(clockwise,if(ix.s == 3){1}else{ix.s+1},if(ix.s == 1){3}else{ix.s-1})
+    start  <- as.numeric(data.extreme[ix.f,out])
+    for(i in 1:length(out))
+      new[,out[i]] <- new$Prop*(finish[i]-start[i]) + start[i]
+    
+    #FOR GRID
+    ix.f <- ifthenelse(clockwise,if(ix.s == 1){3}else{ix.s-1},if(ix.s == 3){1}else{ix.s+1})
+    start  <- as.numeric(data.extreme[ix.f,out])
+    for(i in 1:length(out))
+      new[,paste0(out[i],"end.grid")] <- new$Prop*(finish[i]-start[i]) + start[i]
+    
+    #The tick angles.
+    new$Angle      <- angle + .theme.get.rotation(self)
+    new$Angle.Text <- .valid.angle(angle.text)
+    
+    #Determine the tick finish positions for segments.
+    new$xend <- cos(new$Angle*pi/180)*new$TickLength + new$x
+    new$yend <- sin(new$Angle*pi/180)*new$TickLength + new$y
+    
+    #Determine the secondary tick start and finish positions.
+    new$x.sec    <- new$xend.grid
+    new$y.sec    <- new$yend.grid
+    new$xend.sec <- cos((new$Angle+180)*pi/180)*new$TickLength + new$x.sec
+    new$yend.sec <- sin((new$Angle+180)*pi/180)*new$TickLength + new$y.sec
+    
+    return(new)
+    
+  },error=function(e){
+    warning(e)
+  })
+  
+  return(existing)
+}
+
+.get.seqtlr    <- function(self) c('T','L','R')
+
+.render.fgset <- function(self,data.extreme,scale_details,theme,items){
+  items = .render.ticks(      self,data.extreme,scale_details,theme,items)
+  items = .render.border.main(self,data.extreme,              theme,items)
+  items = .render.border.axis(self,data.extreme,              theme,items)
+  items = .render.labels(     self,data.extreme,scale_details,theme,items)
+  items = .render.arrows(     self,data.extreme,scale_details,theme,items)
+  items
+}
+
+.render.background <- function(self,data.extreme,theme,items){
+  tryCatch({
+      e     <- calc_element('tern.panel.background',theme=theme,verbose=F)
       if(!identical(e,element_blank())){
         grob  <- polygonGrob( data.extreme$x, data.extreme$y, 
                               default.units = "npc",
@@ -283,275 +380,296 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
                                             lty  = e$linetype
                               )
         )
+        items[[length(items) + 1]] <- grob
       }
-  },error = function(e){  warning(e) })
-  items[[length(items) + 1]] <- grob
+  },error = function(e){ 
+    warning(e) 
+  })
   items
 }
 
-.render.borders    <- function(self,data.extreme,theme,items){
+.render.border.main <- function(self,data.extreme,theme,items){
   
-  .render.border = function(name,s,f,items){
-    grob = zeroGrob()
+  tryCatch({
+    e  = calc_element('tern.panel.background',theme,verbose=F)
+    if(identical(e,element_blank())) 
+      return(items)
+    
+    grob     <- polygonGrob(  x = data.extreme$x,
+                              y = data.extreme$y,
+                              default.units = "npc",
+                              id   = rep(1,nrow(data.extreme)),
+                              gp   = gpar(  col  = e$colour, 
+                                            fill = NA, 
+                                            lwd  = is.numericor(e$size,0)*find_global_tern(".pt"), 
+                                            lty  = e$linetype)
+    )
+    items[[length(items) + 1]] = grob
+  },error=function(e){})
+  
+  items
+}
+
+.render.border.axis <- function(self,data.extreme,theme,items,X=.get.seqtlr()){
+  
+  #Only Unique Entries
+  X = unique(X)
+  
+  #Checks
+  seq.tlr = .get.seqtlr()
+  if(any(!{X %in% seq.tlr})) stop('Invalid X')
+  
+  grobs = function(name,s,f,items){
     tryCatch({
       e = calc_element(name,theme=theme,verbose=FALSE)
       if(identical(e,element_blank()))return(items)
       grob = segmentsGrob(
-          x0 = data.extreme$x[s], x1 = data.extreme$x[f], y0 = data.extreme$y[s], y1 = data.extreme$y[f],
+          x0 = data.extreme$x[s], 
+          x1 = data.extreme$x[f], 
+          y0 = data.extreme$y[s], 
+          y1 = data.extreme$y[f],
           default.units="npc",
           gp = gpar(col     = e$colour, 
                     lty     = e$linetype,
                     lineend = e$lineend,
                     lwd     = e$size*find_global_tern(".pt"))
       )
+      items[[length(items) + 1]] <- grob
     },error=function(e){
       warning(e)
     })
-    items[[length(items) + 1]] <- grob
     items
   }
-  
-  #Render the Border
-  .render.mainborder <- function(items){
-    tryCatch({
-      e  = calc_element('tern.plot.background',theme,verbose=F)
-      if(identical(e,element_blank())) return(items)
-      grob     <- polygonGrob(  x = data.extreme$x,
-                                y = data.extreme$y,
-                                default.units = "npc",
-                                id   = rep(1,nrow(data.extreme)),
-                                gp   = gpar(  col  = e$colour, 
-                                              fill = NA, 
-                                              lwd  = is.numericor(e$size,0)*find_global_tern(".pt"), 
-                                              lty  = e$linetype)
-      )
-      items[[length(items) + 1]] = grob
-    },error=function(e){})
-    items
+ 
+  f = if(.theme.get.clockwise(theme)) c(2,3,1) else c(3,1,2)
+  for(x in X){
+    s      = which(seq.tlr == x)
+    name   = sprintf("tern.axis.line.%s",seq.tlr[s])
+    items  = grobs(name,s,f[s],items)
   }
-  
-  #Process the main border
-  items <- .render.mainborder(items)
-  
-  #process the axes
-  if(.theme.get.clockwise(theme)){
-    items <- .render.border("tern.axis.line.T",2,1,items)
-    items <- .render.border("tern.axis.line.L",3,2,items)
-    items <- .render.border("tern.axis.line.R",1,3,items)
-  }else{
-    items <- .render.border("tern.axis.line.T",3,1,items)
-    items <- .render.border("tern.axis.line.L",1,2,items)
-    items <- .render.border("tern.axis.line.R",2,3,items)
-  }
-  
   items
 }
 
-.render.grids      <- function(self,data.extreme,scale_details,theme,items,onBackground=TRUE){
-  #Process the flags.
-  clockwise     <- .theme.get.clockwise(theme)
-  outside       <- .theme.get.outside(theme)
-  showprimary   <- .theme.get.showprimary(theme)
-  showsecondary <- .theme.get.showsecondary(theme)
-  showgrid.major<- .theme.get.showgrid.major(theme)
-  showgrid.minor<- .theme.get.showgrid.minor(theme)
-  showlabels    <- .theme.get.showlabels(theme)
+.render.ticks  <- function(self,data.extreme,scale_details,theme,items,X=.get.seqtlr()){
   
-  #major & minor ticklength
-  tl.major <- tl.minor <- 0
-  tryCatch({
-    tl.major <- convertUnit(theme$tern.axis.ticks.length.major,"npc",valueOnly=T)
-    tl.minor <- convertUnit(theme$tern.axis.ticks.length.minor,"npc",valueOnly=T)
-  },error=function(e){  warning(e) })
+  #Only Unique Entries
+  X = unique(X)
   
-  #Top, Left Right sequence.
-  seq.tlr <- c("T","L","R")
+  #Checks
+  seq.tlr = .get.seqtlr()
+  if(any(!{X %in% seq.tlr})) stop('Invalid X')
+
+  outside     = .theme.get.outside(theme)
+  clockwise   = .theme.get.clockwise(theme)
+  primary     = .theme.get.showprimary(theme)
+  secondary   = .theme.get.showsecondary(theme)
+  angle       = .get.angles(clockwise) + (!outside)*180
+  angle.text  = .get.angles.ticklabels(clockwise) + .theme.get.rotation(self)
   
-  #ASSEMBLE THE GRID DATA.
-  .get.data <- function(X,ix,major=TRUE,angle=0,angle.text=0){
-    existing = data.frame()
-    tryCatch({
-      scale = self$scales[[X]]
-      
-      #DETERMINE THE BREAKS
-      breaks <- if(major){ scale$breaks }else{ scale$minor_breaks }
-      
-      #BYPASS IF NECESSARY
-      if(length(breaks) == 0) return(existing)
-      
-      labels <- ifthenelse(major,scale$labels,"")
-      labels <- as.character(ifthenelse(identical(labels,waiver()),100*breaks,labels))
-      
-      #Assign new id.
-      id <- (max(existing$ID,0) + 1)
-      limits <- is.numericor(scale$limits,c(0,1))
-      ix     <- min(ix,ifthenelse(major,length(tl.major),length(tl.minor)))
-      majmin <- ifthenelse(major,"major","minor")  #Major or Minor Element Name part.
-      
-      #The new dataframe
-      new            <- data.frame(ID = id,Scale=X,breaks,Labels=labels,Major=major)
-      new            <- subset(new,breaks >= min(limits) & breaks <= max(limits))
-      new$Prop       <- (new$breaks - min(limits)) / abs(diff(limits))
-      new$TickLength <- ifthenelse(major,tl.major[ix],tl.minor[ix])
-      new$NameText   <- paste0("tern.axis.text.",X)
-      new$NameTicks  <- paste0("tern.axis.ticks.",majmin,".",X)
-      new$NameGrid   <- paste0("tern.panel.grid.",majmin,".",X)
-      new$Major      <- major
-      
-      ##Start and finish positions of scale.
-      out       <- c("x","y")
-      
-      #Start indexes.
-      ix.s <- which(seq.tlr == X);
-      finish <- as.numeric(data.extreme[ix.s,out])
-      
-      #For Ticks
-      ix.f <- ifthenelse(clockwise,if(ix.s == 3){1}else{ix.s+1},if(ix.s == 1){3}else{ix.s-1})
-      start  <- as.numeric(data.extreme[ix.f,out])
-      for(i in 1:length(out))
-        new[,out[i]] <- new$Prop*(finish[i]-start[i]) + start[i]
-      
-      #FOR GRID
-      ix.f <- ifthenelse(clockwise,if(ix.s == 1){3}else{ix.s-1},if(ix.s == 3){1}else{ix.s+1})
-      start  <- as.numeric(data.extreme[ix.f,out])
-      for(i in 1:length(out))
-        new[,paste0(out[i],"end.grid")] <- new$Prop*(finish[i]-start[i]) + start[i]
-      
-      #The tick angles.
-      new$Angle      <- angle + .theme.get.rotation(self)
-      new$Angle.Text <- .valid.angle(angle.text)
-      
-      #Determine the tick finish positions for segments.
-      new$xend <- cos(new$Angle*pi/180)*new$TickLength + new$x
-      new$yend <- sin(new$Angle*pi/180)*new$TickLength + new$y
-      
-      #Determine the secondary tick start and finish positions.
-      new$x.sec    <- new$xend.grid
-      new$y.sec    <- new$yend.grid
-      new$xend.sec <- cos((new$Angle+180)*pi/180)*new$TickLength + new$x.sec
-      new$yend.sec <- sin((new$Angle+180)*pi/180)*new$TickLength + new$y.sec
-      
-      ##ADD TO EXISTING
-      return(rbind(existing,new))
-    },error=function(e){
-      warning(e)
-    })
-    return(existing)
-  }
-  
-  angles      <- .get.angles(clockwise) + (!outside)*180
-  angles.text <- .get.angles.ticklabels(clockwise) + .theme.get.rotation(self)
-  
-  ##get the base data.
-  d = merge(data.frame(ix=1:length(seq.tlr)),data.frame(major=c(T,F)),by=NULL)
-  d = ddply(d,c('major','ix'),function(x){
-    ix = x$ix[1]
-    .get.data(X=seq.tlr[ix],ix=ix, major = x$major[1], angle = angles[ix], angle.text = angles.text[ix]);
-  })
-  if(empty(d)){ return(items) }
-  
-  #FUNCTION TO RENDER TICKS AND LABELS
-  .render.ticks  <- function(name,items,d,primary=TRUE){
-    grob = zeroGrob()
+  #Function to render the grobs
+  grobs  <- function(name,items,df,primary=TRUE){
+    
     tryCatch({  
+      
       e <- calc_element(name,theme=theme,verbose=F)
-      if(identical(e,element_blank()))return(items)
+      
+      if(identical(e,element_blank()))
+        return(items)
+      
       grob     <- segmentsGrob(
-        x0 = ifthenelse(!primary,d$x.sec,d$x), 
-        x1 = ifthenelse(!primary,d$xend.sec,d$xend),
-        y0 = ifthenelse(!primary,d$y.sec,d$y), 
-        y1 = ifthenelse(!primary,d$yend.sec,d$yend),
+        x0 = ifthenelse(!primary,df$x.sec,   df$x), 
+        x1 = ifthenelse(!primary,df$xend.sec,df$xend),
+        y0 = ifthenelse(!primary,df$y.sec,   df$y), 
+        y1 = ifthenelse(!primary,df$yend.sec,df$yend),
         default.units="npc",
         gp = gpar(col     = e$colour, 
                   lty     = e$linetype,
                   lineend = e$lineend,
                   lwd     = e$size*find_global_tern(".pt"))
       )
+      
+      items[[length(items) + 1]] <- grob
+      
     },error = function(e){
       warning(e)
     })
-    items[[length(items) + 1]] <- grob
-    return(items)
+    
+    items
   }
   
+  
+  #Iterate over the values of X
+  for(x in X){
+    
+    #Determine the index
+    ix = which(seq.tlr == x)
+    
+    #Generate the data
+    df = ldply(c(T,F),function(major){
+      .get.grid.data(self,theme,data.extreme,X = x, major = major, angle = angle[ix], angle.text = angle.text[ix])
+    })
+    
+    #If Primary Ticks
+    if(primary)
+      for(name in unique(df$NameTicks)){
+        items = grobs(name = name, items = items, df = df[which(df$NameTicks == name),,drop = F], primary = T)}
+    
+    #If Secondary Ticks
+    if(secondary)
+      for(name in unique(df$NameTicks)){
+        items = grobs(name = name, items = items, df = df[which(df$NameTicks == name),,drop = F], primary = F)}
+  }
+  
+  #Done
+  items
+}
+
+.render.labels <- function(self,data.extreme,scale_details,theme,items,X=.get.seqtlr()){
+  #Only Unique Entries
+  X = unique(X)
+  
+  #Checks
+  seq.tlr = .get.seqtlr()
+  if(any({!X %in% seq.tlr})) 
+    stop('Invalid X')
+
   #Axis labels, ie labels next to ticks
-  .render.labels <- function(name,items,d){ 
-    grob = zeroGrob()
+  grobs <- function(name,items,df,outside,showprimary){ 
     tryCatch({
-      d         = d[which(d$Labels != ''),]
+      df        = df[which(df$Labels != ''),]
       e         = calc_element(name,theme=theme,verbose=F)
-      if(empty(d) || identical(e,element_blank())) return(items)
-      xts       = ifthenelse(outside,d$x,d$xend); xtf = ifthenelse(outside,d$xend,d$x) 
-      yts       = ifthenelse(outside,d$y,d$yend); ytf = ifthenelse(outside,d$yend,d$y) 
-      a         = is.numericor(e$angle,0) + is.numericor(unique(d$Angle.Text)[1],0)
-      dA        = a - atan2(ytf-yts,xtf-xts)*180/pi                  #DEGREES, Angle Difference between Ticks and Labels
+      
+      if(empty(df) || identical(e,element_blank())) 
+        return(items)
+      
+      xts       = ifthenelse(outside,df$x,   df$xend)
+      xtf       = ifthenelse(outside,df$xend,df$x) 
+      yts       = ifthenelse(outside,df$y,   df$yend)
+      ytf       = ifthenelse(outside,df$yend,df$y) 
+      a         = is.numericor(e$angle,0) + is.numericor(unique(df$Angle.Text)[1],0)
+      dA        = a - atan2(ytf-yts,xtf-xts)*180/pi                   #DEGREES, Angle Difference between Ticks and Labels
       hj        = +cos((dA-180)*pi/180)*0.5 + is.numericor(e$hjust,0) #BACK TO RADIANS
       vj        = -sin((dA-180)*pi/180)*0.5 + is.numericor(e$vjust,0) #BACK TO RADIANS
-      grob      = textGrob( label          = label_formatter(as.character(d$Labels)), 
-                             x             = ifthenelse(showprimary || !outside,xtf,xts) + convertX(cos(pi*(d$Angle + (!outside)*180)/180)*unit(2,'pt'),'npc',valueOnly = T),
-                             y             = ifthenelse(showprimary || !outside,ytf,yts) + convertY(sin(pi*(d$Angle + (!outside)*180)/180)*unit(2,'pt'),'npc',valueOnly = T),
-                             default.units ="npc", 
-                             hjust         = is.numericor(hj,0.5),
-                             vjust         = is.numericor(vj,0.5),
-                             rot           = a, 
-                             gp            = gpar(col        = e$colour, 
-                                                  fontsize   = e$size,
-                                                  fontfamily = ifthenelse(is.character(e$family),e$family,"sans"), 
-                                                  fontface   = e$face, 
-                                                  lineheight = ifthenelse(is.numeric(e$lineheight),e$lineheight,1)))
-    },error = function(e){  warning(e)  })
-    items[[length(items) + 1]] <- grob
-    return(items)
+      grob      = textGrob( label         = label_formatter(as.character(df$Labels)), 
+                            x             = ifthenelse(showprimary || !outside,xtf,xts) + convertX(cos(pi*(df$Angle + (!outside)*180)/180)*unit(2,'pt'),'npc',valueOnly = T),
+                            y             = ifthenelse(showprimary || !outside,ytf,yts) + convertY(sin(pi*(df$Angle + (!outside)*180)/180)*unit(2,'pt'),'npc',valueOnly = T),
+                            default.units ="npc", 
+                            hjust         = is.numericor(hj,0.5),
+                            vjust         = is.numericor(vj,0.5),
+                            rot           = a, 
+                            gp            = gpar(col        = e$colour, 
+                                                 fontsize   = e$size,
+                                                 fontfamily = ifthenelse(is.character(e$family),e$family,"sans"), 
+                                                 fontface   = e$face, 
+                                                 lineheight = ifthenelse(is.numeric(e$lineheight),e$lineheight,1)))
+      items[[length(items) + 1]] <- grob
+    },error = function(e){  
+      print(e)
+      warning(e)  
+    })
+    items
   }
   
-  .render.grid   <- function(name,items,d,showgrid.major=TRUE,showgrid.minor=TRUE){
-    if((unique(d$Major) & showgrid.major) | (!unique(d$Major) & showgrid.minor)){
-      grob = zeroGrob()
+  showLabels = .theme.get.showlabels(theme)
+  if(showLabels){
+    
+    outside     = .theme.get.outside(theme)
+    clockwise   = .theme.get.clockwise(theme)
+    showprimary = .theme.get.showprimary(theme)
+    angle       = .get.angles(clockwise) + (!outside)*180
+    angle.text  = .get.angles.ticklabels(clockwise) + .theme.get.rotation(self)
+
+    #Generate the data
+    df = ldply(X,function(x){
+      ix =  which(seq.tlr == x)
+      .get.grid.data(self,theme,data.extreme,X = x, major = TRUE, angle = angle[ix], angle.text = angle.text[ix])
+    })
+    
+    for(name in unique(df$NameText)){
+      items <- grobs(name=name,items=items,df=df[which(df$NameText  == name),,drop=F],outside,showprimary)
+    }
+  }
+  items
+}
+
+.render.grid <- function(self,data.extreme,scale_details,theme,items,X=.get.seqtlr()){
+  
+  #Only Unique Entries
+  X = unique(X)
+  
+  #Checks
+  seq.tlr = .get.seqtlr()
+  if(any({!X %in% seq.tlr})) 
+    stop('Invalid X')
+  
+  #Process the flags.
+  clockwise     <- .theme.get.clockwise(theme)
+  outside       <- .theme.get.outside(theme)
+  showgrid.major<- .theme.get.showgrid.major(theme)
+  showgrid.minor<- .theme.get.showgrid.minor(theme)
+  
+  #Get the Angles
+  angle      <- .get.angles(clockwise) + (!outside)*180
+  angle.text <- .get.angles.ticklabels(clockwise) + .theme.get.rotation(self)
+  
+  ##get the base data.
+  df = expand.grid(ix=seq_along(seq.tlr),major=c(T,F))
+  df = ddply(df,c('major','ix'),function(x){
+    .get.grid.data(self,theme,data.extreme,X = seq.tlr[x$ix], major = x$major, angle = angle[x$ix], angle.text = angle.text[x$ix])
+  })
+  
+  #If Nothing in 'd', return the curent list of items
+  if(empty(df))
+    return(items)
+  
+  grobs   <- function(name,items,df,showgrid.major=TRUE,showgrid.minor=TRUE){
+    if((unique(df$Major) & showgrid.major) | (!unique(df$Major) & showgrid.minor)){
       tryCatch({  
         e    = calc_element(name,theme=theme,verbose=F)
-        if(identical(e,element_blank()))return(items)
+        
+        if(identical(e,element_blank()))
+          return(items)
+        
         grob = segmentsGrob(
-          x0 = d$x, 
-          x1 = d$xend.grid,
-          y0 = d$y, 
-          y1 = d$yend.grid,
+          x0 = df$x, 
+          x1 = df$xend.grid,
+          y0 = df$y, 
+          y1 = df$yend.grid,
           default.units="npc",
           gp = gpar(col     = e$colour, 
                     lty     = e$linetype,
                     lineend = e$lineend,
                     lwd     = e$size*find_global_tern(".pt"))
         )
+        items[[length(items) + 1]] <- grob
+        
       },error = function(e){ 
         warning(e)
       })
-      items[[length(items) + 1]] <- grob
     }
-    return(items)
+    items
   }
   
   #PROCESS TICKS AND LABELS
-  if(onBackground){
-    if(showgrid.major | showgrid.minor){
-      for(n in unique(d$NameGrid)){ 
-        items <- .render.grid(  name=n,items=items,d=d[which(d$NameGrid  == n),], showgrid.major=showgrid.major,showgrid.minor=showgrid.minor)
-      } 
-    }
-  }else{
-    if(showprimary)
-      for(n in unique(d$NameTicks)){items <- .render.ticks(name=n,items=items,d=d[which(d$NameTicks == n),],primary=TRUE)}
-    if(showsecondary)
-      for(n in unique(d$NameTicks)){items <- .render.ticks(name=n,items=items,d=d[which(d$NameTicks == n),],primary=FALSE)}
-    if(showlabels)
-      for(n in unique(d$NameText)){ items <- .render.labels(name=n,items=items,d=d[which(d$NameText  == n),])}
+  if(showgrid.major | showgrid.minor){
+    for(name in unique(df$NameGrid)){ 
+      items <- grobs(name=name, items=items, df = df[ which(df$NameGrid  == name),,drop=FALSE], 
+                     showgrid.major = showgrid.major, showgrid.minor = showgrid.minor)
+    } 
   }
+  
   items
 }
 
-.render.titles     <- function(self,data.extreme,scale_details,theme,items){
+
+.render.titles <- function(self,data.extreme,scale_details,theme,items){
+  
+  if(!.theme.get.showtitles(theme)) 
+    return(items)
+  
   sidelength = sqrt( diff(data.extreme$x[1:2])^2 + diff(data.extreme$y[1:2])^2)
-  if(!.theme.get.showtitles(theme)) return(items)
+  
   .render.title = function(name,ix,items){
-    grob = zeroGrob()
     tryCatch({
       e     <- calc_element(name,theme=theme,verbose=F)
       if(identical(e,element_blank()))return(items)
@@ -575,7 +693,7 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
                                    fontfamily = ifthenelse(is.character(e$family),e$family,"sans"), 
                                    fontface   = e$face, 
                                    lineheight = e$lineheight))
-    items[[length(items) + 1]] <- grob
+      items[[length(items) + 1]] <- grob
     },error = function(e){
       warning(e)
     })
@@ -586,10 +704,15 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
   items <- .render.title("tern.axis.title.T",1,items)
   items <- .render.title("tern.axis.title.L",2,items)
   items <- .render.title("tern.axis.title.R",3,items)
+  items
 }
 
-.render.arrows     <- function(self,data.extreme,details,theme,items){
-  if(!.theme.get.showarrows(theme))return(items)
+# The Arrows Parallel to the Axes
+.render.arrows <- function(self,data.extreme,details,theme,items){
+  
+  if(!.theme.get.showarrows(theme))
+    return(items)
+  
   tryCatch({
     
     #clockwise or anticlockwise precession
@@ -634,10 +757,10 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
     }
     
     #Cut down to relative proportion.
-    dx = (d.f - d.s)
+    dx   = (d.f - d.s)
     d.f <- d.f - (1-arrowfinish)*dx
     d.s <- d.s +      arrowstart*dx
-    d <- rbind(d.s,d.f)
+    d   <- rbind(d.s,d.f)
     
     #Determine the start and end positions
     ixseq <- names(self$mapping)
@@ -681,9 +804,8 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
     
     ##Function to create new arrow grob
     .render.arrow <- function(name,ix,items){
-      grob = zeroGrob()
       tryCatch({  
-        e    = calc_element(name,theme=theme,verbose=F)
+        e = calc_element(name,theme=theme,verbose=F)
         if(identical(e,element_blank()))return(items)
         grob = segmentsGrob(x0 = d$x[ix], x1 = d$xend[ix], y0 = d$y[ix], y1 = d$yend[ix],
                             default.units ="npc",
@@ -693,16 +815,15 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
                                                  lineend = 'butt',
                                                  lwd     = e$size*find_global_tern(".pt"))
         )
+        items[[length(items) + 1]] <- grob
       },error = function(e){
         warning(e)
       })
-      items[[length(items) + 1]] <- grob
-      return(items)
+      items
     }
     
     #Function to greate new label grob
     .render.label <- function(name,ix,items){
-      grob = zeroGrob()
       tryCatch({  
         e    = calc_element(name,theme=theme,verbose=F)
         if(identical(e,element_blank()))return(items)
@@ -719,22 +840,28 @@ CoordTern <- ggproto("CoordTern", CoordCartesian,
                                      fontfamily = e$family, 
                                      fontface   = e$face, 
                                      lineheight = e$lineheight))
-      },error = function(e){ warning(e) })
-      items[[length(items) + 1]] <- grob
+        items[[length(items) + 1]] <- grob
+      },error = function(e){ 
+        warning(e) 
+      })
       items
     }
   
     #process the axes
     for(i in 1:length(ixseq)){
       items <- .render.arrow(paste0("tern.axis.arrow.",     ixseq[i]),i,items) #Arrows
+    }
+    for(i in 1:length(ixseq)){
       items <- .render.label(paste0("tern.axis.arrow.text.",ixseq[i]),i,items) #Markers
     }
-  },error=function(e){ 
+    
+  },error=function(e){
     message(e)
   })
   items
 }
 
+
 .rotation = function (xy, angle, degrees=TRUE) {
   if(degrees) angle = pi*angle/180
   xy <- as.matrix(xy)
