@@ -28,11 +28,8 @@ ggplot_build <- function(plot) {
   }
   
   #Add the Missing Clipping Mask if necessary
-  if(isTernary){
-    theme <- ggint$plot_theme(plot) #NH
-    if(calc_element('tern.panel.mask.show',theme) %||% TRUE)
-      plot <- layers_add_missing_mask(plot)
-  }
+  if(isTernary)
+    plot <- layers_add_or_remove_mask(plot)
   
   #Check the Layers
   layers <- plot$layers
