@@ -1,5 +1,3 @@
-.theme_arrows <- function(show){theme(axis.tern.showarrows = show)}
-
 #' Show or Hide the Ternary Arrows
 #' 
 #' \code{theme_noarrows} is a function that appends to the current theme a flag to switch OFF the ternary arrows
@@ -15,4 +13,9 @@ theme_hidearrows <- theme_noarrows
 #' \code{theme_showarrows} is a function that appends to the current theme a flag to switch ON the ternary arrows
 #' @rdname themeshowhidearrows
 #' @export
-theme_showarrows <- function(){.theme_arrows(TRUE)}
\ No newline at end of file
+theme_showarrows <- function(){.theme_arrows(TRUE)}
+
+#internal function
+.theme_arrows <- function(show){
+  theme(tern.axis.arrow.show = show)
+}
\ No newline at end of file
